emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] emacs/lisp/mail unrmail.el


From: Glenn Morris
Subject: [Emacs-diffs] emacs/lisp/mail unrmail.el
Date: Tue, 27 Jan 2009 03:41:25 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Glenn Morris <gm>       09/01/27 03:41:25

Modified files:
        lisp/mail      : unrmail.el 

Log message:
        (command-line-args-left): Remove unneeded declaration.
        (batch-unrmail, unrmail): Doc fix.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/emacs/lisp/mail/unrmail.el?cvsroot=emacs&r1=1.26&r2=1.27

Patches:
Index: unrmail.el
===================================================================
RCS file: /sources/emacs/emacs/lisp/mail/unrmail.el,v
retrieving revision 1.26
retrieving revision 1.27
diff -u -b -r1.26 -r1.27
--- unrmail.el  5 Jan 2009 03:22:38 -0000       1.26
+++ unrmail.el  27 Jan 2009 03:41:25 -0000      1.27
@@ -1,7 +1,7 @@
 ;;; unrmail.el --- convert Rmail files to mailbox files
 
-;; Copyright (C) 1992, 2001, 2002, 2003, 2004, 2005,
-;;   2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+;; Copyright (C) 1992, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+;;   2009  Free Software Foundation, Inc.
 
 ;; Maintainer: FSF
 ;; Keywords: mail
@@ -25,16 +25,13 @@
 
 ;;; Code:
 
-(defvar command-line-args-left)        ;Avoid 'free variable' warning
-
 ;;;###autoload
 (defun batch-unrmail ()
-  "Convert Rmail files to system inbox format.
-Specify the input Rmail file names as command line arguments.
+  "Convert old-style Rmail Babyl files to system inbox format.
+Specify the input Rmail Babyl file names as command line arguments.
 For each Rmail file, the corresponding output file name
 is made by adding `.mail' at the end.
 For example, invoke `emacs -batch -f batch-unrmail RMAIL'."
-  ;; command-line-args-left is what is left of the command line (from 
startup.el)
   (if (not noninteractive)
       (error "`batch-unrmail' is to be used only with -batch"))
   (let ((error nil))
@@ -50,8 +47,8 @@
 
 ;;;###autoload
 (defun unrmail (file to-file)
-  "Convert Rmail file FILE to system inbox format file TO-FILE."
-  (interactive "fUnrmail (rmail file): \nFUnrmail into (new mailbox file): ")
+  "Convert old-style Rmail Babyl file FILE to system inbox format file 
TO-FILE."
+  (interactive "fUnrmail (babyl file): \nFUnrmail into (new mailbox file): ")
   (with-temp-buffer
     ;; Read in the old Rmail file with no decoding.
     (let ((coding-system-for-read 'raw-text))
@@ -225,6 +222,5 @@
 
 (provide 'unrmail)
 
-;;; unrmail.el ends here
-
 ;; arch-tag: 14c6290d-60b2-456f-8909-5c2387de6acb
+;;; unrmail.el ends here
@@ -1,7 +1,7 @@
-;;; unrmail.el --- convert Rmail files to mailbox files
+;;; unrmail.el --- convert Rmail Babyl files to mailbox files
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]